![WSS Logo](https://github.com/kenmalik/wilderness-survival-system/blob/de71a00ddf02ef59b48a85b331612210cf47c941/assets/logo.png)

# Wilderness Survival System

## Description

The Wilderness Survival System (WSS) is a "game" which emulates surviving in an
unknown wilderness. Players are placed randomly on the west side of the map and
make decisions to try and get to the east side of the map. After the players are
placed, the game runs itself (similar to John Conway's Game of Life).

## Usage

Install the game using `pipx`

```
pipx install wss-py
```

To play simply run the following command

```
wss
```
